@@ -74,7 +74,7 @@ class UnixSocket(BaseSocket):
         return "unix:%s" % self.address
         
     def bind(self, sock):
-        old_umask = os.umask(self.conf['umask'])
+        old_umask = os.umask(self.conf.umask)
         sock.bind(self.address)
         util.chown(self.address, self.conf.uid, self.conf.gid)
         os.umask(old_umask)
