@@ -20,7 +20,7 @@ class GEventWorker(AsyncWorker):
     @classmethod  
     def setup(cls):
         from gevent import monkey
-        monkey.patch_all()
+        monkey.patch_all(dns=False)
         
     def keepalive_request(self, client, addr):
         req = None
@@ -35,7 +35,7 @@ class GEventWorker(AsyncWorker):
         acceptor = gevent.spawn(self.acceptor, pool)
         
         try:
-            while True:
+            while self.alive:
                 self.notify()
             
                 if self.ppid != os.getppid():
@@ -47,6 +47,7 @@ class GEventWorker(AsyncWorker):
             pool.join(timeout=self.timeout)
         except KeyboardInterrupt:
             pass
+        os._exit(3)
 
     def acceptor(self, pool):
         gevent.getcurrent()
@@ -59,6 +60,9 @@ class GEventWorker(AsyncWorker):
                 conn, addr, gt = None, None, None
             except greenlet.GreenletExit:
                 return
+            except:
+                self.log.exception("Unexpected error in acceptor. Sepuku.")
+                os._exit(4)
           
     def cleanup(self, gt):
         try:
